@@ -1,7 +1,7 @@
 from collections import namedtuple
 from typing import _LiteralGenericAlias, get_args  # type: ignore # noqa
 
-from .lookup import READOUT_PLATFORMS, READOUT_TYPES
+from .lookup import READOUT_PLATFORMS, readoutS
 
 
 def _todict(x: _LiteralGenericAlias) -> dict:
@@ -16,8 +16,8 @@ class ReadoutType:
 
     @classmethod
     def lookup(cls):
-        values = _todict(READOUT_TYPES)
-        nt = namedtuple("readout_type", values.keys())
+        values = _todict(readoutS)
+        nt = namedtuple("readout", values.keys())
         return nt(**values)
 
 
@@ -27,9 +27,9 @@ class ReadoutPlatform:
     @classmethod
     def lookup(cls):
         values = _todict(READOUT_PLATFORMS)
-        nt = namedtuple("readout_type", values.keys())
+        nt = namedtuple("readout", values.keys())
         return nt(**values)
 
 
-readout_type = ReadoutType.lookup()
+readout = ReadoutType.lookup()
 readout_platform = ReadoutPlatform.lookup()
