@@ -74,6 +74,15 @@ class EFO(EntityTable):
 
     def get_readout(self, term_id):
         """Get readout attributes from EFO id."""
+
+        def _list_to_str(lst: list):
+            if len(lst) == 0:
+                return None
+            elif len(lst) == 1:
+                return lst[0].name  # type: ignore
+            else:
+                return ";".join([i.name for i in lst])
+
         term = self.ontology.get_term(term_id)
         superclasses = term.superclasses()
 
@@ -86,16 +95,12 @@ class EFO(EntityTable):
         # get the measurement for non-molecular readouts
         measurements = [i for i in self.measurement if i in superclasses]
 
-        molecule = None if len(molecules) == 0 else [i.name for i in molecules]
-        instrument = None if len(instruments) == 0 else [i.name for i in instruments]
-        measurement = None if len(measurements) == 0 else [i.name for i in measurements]
-
         readout = {
             "efo_id": term_id,
             "name": term.name,
-            "molecule": molecule,
-            "instrument": instrument,
-            "measurement": measurement,
+            "molecule": _list_to_str(molecules),
+            "instrument": _list_to_str(instruments),
+            "measurement": _list_to_str(measurements),
         }
 
         return readout
